from typing import Any

def bind_operation(
    version,
    authentication,
    name: str = ...,
    password: Any | None = ...,
    sasl_mechanism: Any | None = ...,
    sasl_credentials: Any | None = ...,
    auto_encode: bool = ...,
): ...
def bind_request_to_dict(request): ...
def bind_response_operation(
    result_code,
    matched_dn: str = ...,
    diagnostic_message: str = ...,
    referral: Any | None = ...,
    server_sasl_credentials: Any | None = ...,
): ...
def bind_response_to_dict(response): ...
def sicily_bind_response_to_dict(response): ...
def bind_response_to_dict_fast(response): ...
def sicily_bind_response_to_dict_fast(response): ...
