from datetime import tzinfo
from typing import Any

class OffsetTzInfo(tzinfo):
    offset: Any
    name: Any
    def __init__(self, offset, name) -> None: ...
    def utcoffset(self, dt): ...
    def tzname(self, dt): ...
    def dst(self, dt): ...
    def __getinitargs__(self): ...
