STATE_ANY: int
STATE_ESCAPE: int
STATE_ESCAPE_HEX: int

def to_dn(
    iterator, decompose: bool = ..., remove_space: bool = ..., space_around_equal: bool = ..., separate_rdn: bool = ...
): ...
def parse_dn(dn, escape: bool = ..., strip: bool = ...): ...
def safe_dn(dn, decompose: bool = ..., reverse: bool = ...): ...
def safe_rdn(dn, decompose: bool = ...): ...
def escape_rdn(rdn: str) -> str: ...
